@@ -69,6 +69,7 @@ class User(object):
             owner = get_owner(self.token)
             log.debug("got owner=%s, adding to memo", owner)
             User._token2id[self.token] = owner
+            _ensure_intermediate_dirs(fname)
             with open(fname, "w") as f:
                 json.dump(User._token2id, f, sort_keys=True, indent=2)
         else:
@@ -161,6 +162,7 @@ class Puzzle(object):
         fname = "{}_{:02d}".format(self.year, self.day)
         prefix = os.path.join(self.user.memo_dir, fname)
         self.input_data_fname = prefix + "_input.txt"
+        self.example_input_data_fname = prefix + "_example_input.txt"
         self.answer_a_fname = prefix + "a_answer.txt"
         self.answer_b_fname = prefix + "b_answer.txt"
         self.incorrect_answers_a_fname = prefix + "a_bad_answers.txt"
@@ -178,10 +180,6 @@ class Puzzle(object):
 
     @property
     def input_data(self):
-        if self.user.token == ".aocr":
-            with open("input.txt") as f:
-                return f.read()
-        sanitized = "..." + self.user.token[-4:]
         try:
             # use previously received data, if any existing
             with io.open(self.input_data_fname, encoding="utf-8") as f:
@@ -190,9 +188,9 @@ class Puzzle(object):
             if err.errno != errno.ENOENT:
                 raise
         else:
-            sanitized_path = self.input_data_fname.replace(self.user.token, sanitized)
-            log.debug("reusing existing data %s", sanitized_path)
+            log.debug("reusing existing data %s", self.input_data_fname)
             return data.rstrip("\r\n")
+        sanitized = "..." + self.user.token[-4:]
         log.info("getting data year=%s day=%s token=%s", self.year, self.day, sanitized)
         response = requests.get(
             url=self.input_data_url, cookies=self.user.auth, headers=USER_AGENT
@@ -210,6 +208,28 @@ class Puzzle(object):
             f.write(data)
         return data.rstrip("\r\n")
 
+    @property
+    def example_data(self):
+        try:
+            with io.open(self.example_input_data_fname, encoding="utf-8") as f:
+                data = f.read()
+        except (IOError, OSError) as err:
+            if err.errno != errno.ENOENT:
+                raise
+        else:
+            log.debug("reusing existing example data %s", self.example_input_data_fname)
+            return data.rstrip("\r\n")
+        soup = self._soup()
+        try:
+            data = soup.pre.text
+        except Exception:
+            log.info("unable to find example data year=%s day=%s", self.year, self.day)
+            data = ""
+        with open(self.example_input_data_fname, "w") as f:
+            log.info("saving the example data")
+            f.write(data)
+        return data.rstrip("\r\n")
+
     @property
     def title(self):
         if os.path.isfile(self.title_fname):
@@ -305,7 +325,6 @@ class Puzzle(object):
         if part == "b" and value == getattr(self, "answer_a", None):
             raise AocdError("cowardly refusing to re-submit answer_a ({}) for part b".format(value))
         url = self.submit_url
-        sanitized = "..." + self.user.token[-4:]
         check_guess = self._check_guess_against_existing(value, part)
         if check_guess is not None:
             if quiet:
@@ -313,6 +332,7 @@ class Puzzle(object):
             else:
                 print(check_guess)
             return
+        sanitized = "..." + self.user.token[-4:]
         log.info("posting %r to %s (part %s) token=%s", value, url, part, sanitized)
         level = {"a": 1, "b": 2}[part]
         response = requests.post(
@@ -434,7 +454,7 @@ class Puzzle(object):
     def _get_answer(self, part):
         """
         Note: Answers are only revealed after a correct submission. If you've
-        have not already solved the puzzle, PuzzleUnsolvedError will be raised.
+        not already solved the puzzle, PuzzleUnsolvedError will be raised.
         """
         if part == "b" and self.day == 25:
             return ""
@@ -526,3 +546,11 @@ def _parse_duration(s):
     return timedelta(hours=h, minutes=m, seconds=s)
 
 
+def _load_users():
+    path = os.path.join(AOCD_CONFIG_DIR, "tokens.json")
+    try:
+        with open(path) as f:
+            users = json.load(f)
+    except IOError:
+        users = {"default": default_user().token}
+    return users
